import type { DoubleMatrix } from '../types';
export interface MatrixPQNOptions {
    /**
     * Normalization integral constant.
     * @default 100
     */
    max?: number;
    /**
     * min
     */
    min?: number;
}
/**
 * Performs a Probabilistic quotient normalization (PQN) over the dataset to account dilution based in median spectrum.
 * Dieterle, F., Ross, A., Schlotterbeck, G., & Senn, H. (2006). Probabilistic quotient normalization as robust method to account for dilution of complex biological mixtures. Application in 1H NMR metabonomics. Analytical chemistry, 78(13), 4281-4290.
 * DOI: 10.1021/ac051632c
 * @param matrix - matrix [rows][cols].
 * @param options - options
 * @returns - {data: Normalized dataset, medianOfQuotients: The median of quotients of each variables}
 */
export declare function matrixPQN(matrix: DoubleMatrix, options?: MatrixPQNOptions): {
    data: number[][];
    medianOfQuotients: number[];
};
//# sourceMappingURL=matrixPQN.d.ts.map