"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.matrixZPivotRescale = matrixZPivotRescale;
const matrixCreateEmpty_1 = require("./matrixCreateEmpty");
const matrixMaxAbsoluteZ_1 = require("./matrixMaxAbsoluteZ");
/**
 * Rescale a matrix around 0 taking into account the absolute max value.
 * @param matrix - matrix [rows][cols].
 * @param options - Options.
 */
function matrixZPivotRescale(matrix, options = {}) {
    const { max = 1, ArrayConstructor } = options;
    const nbColumns = matrix[0].length;
    const nbRows = matrix.length;
    const newMatrix = (0, matrixCreateEmpty_1.matrixCreateEmpty)({ nbColumns, nbRows, ArrayConstructor });
    const currentMax = (0, matrixMaxAbsoluteZ_1.matrixMaxAbsoluteZ)(matrix);
    for (let column = 0; column < nbColumns; column++) {
        const factor = max / currentMax;
        for (let row = 0; row < nbRows; row++) {
            newMatrix[row][column] = matrix[row][column] * factor;
        }
    }
    return newMatrix;
}
//# sourceMappingURL=matrixZPivotRescale.js.map