"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.matrixZRescale = matrixZRescale;
const matrixCreateEmpty_1 = require("./matrixCreateEmpty");
const matrixMinMaxZ_1 = require("./matrixMinMaxZ");
/**
 * Rescale a matrix between min and max values.
 * @param matrix - matrix [rows][cols].
 * @param options - Options.
 */
function matrixZRescale(matrix, options = {}) {
    const { min = 0, max = 1, ArrayConstructor } = options;
    const nbColumns = matrix[0].length;
    const nbRows = matrix.length;
    const newMatrix = (0, matrixCreateEmpty_1.matrixCreateEmpty)({ nbColumns, nbRows, ArrayConstructor });
    const { min: currentMin, max: currentMax } = (0, matrixMinMaxZ_1.matrixMinMaxZ)(matrix);
    const factor = (max - min) / (currentMax - currentMin);
    for (let column = 0; column < nbColumns; column++) {
        for (let row = 0; row < nbRows; row++) {
            newMatrix[row][column] =
                (matrix[row][column] - currentMin) * factor + min;
        }
    }
    return newMatrix;
}
//# sourceMappingURL=matrixZRescale.js.map