"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.simpleNormInv = simpleNormInv;
exports.simpleNormInvNumber = simpleNormInvNumber;
const erfcinv_1 = __importDefault(require("./erfcinv"));
/**
 * Applies a simple normalization inverse transformation to the input data.
 * @param data - The input array of numbers to be transformed.
 * @param options - Optional parameters for the transformation.
 * @returns A new Float64Array containing the transformed data.
 */
function simpleNormInv(data, options = {}) {
    const { magnitudeMode = false } = options;
    const result = new Float64Array(data.length);
    if (magnitudeMode) {
        for (let i = 0; i < result.length; i++) {
            result[i] = -Math.sqrt(-2 * Math.log(1 - data[i]));
        }
    }
    else {
        for (let i = 0; i < result.length; i++) {
            result[i] = -1 * Math.SQRT2 * (0, erfcinv_1.default)(2 * data[i]);
        }
    }
    return result;
}
/**
 * Convenience wrapper for single number processing by simpleNormInv function.
 * @param data - The number to be normalized.
 * @param options - The options for the normalization process.
 * @returns The normalized number.
 */
function simpleNormInvNumber(data, options = {}) {
    return simpleNormInv([data], options)[0];
}
//# sourceMappingURL=simpleNormInv.js.map