import type { NumberArray } from 'cheminfo-types';
export interface XBoxPlotWithOutliers {
    /**
     * The minimum value of the number array
     */
    min: number;
    /**
     * q1 - 1.5 * IQR
     */
    lowerWhisker: number;
    /**
     * The minimum value of the number array that is not an outlier
     */
    minWhisker: number;
    /**
     * The first quartile of the number array
     */
    q1: number;
    /**
     * The median of the number array
     */
    median: number;
    /**
     * The third quartile of the number array
     */
    q3: number;
    /**
     * q3 + 1.5 * IQR
     */
    maxWhisker: number;
    /**
     * The maximal value of the number array that is not an outlier
     */
    upperWhisker: number;
    /**
     * The maximum value of the number array
     */
    max: number;
    /**
     * q3 - q1
     */
    iqr: number;
    /**
     * The outliers of the number array based on 1.5 * IQR
     */
    outliers: number[];
}
/**
 * Calculating the box plot of the array with outliers
 * Values are outliers if they are below Q1 - 1.5 * IQR or above Q3 + 1.5 * IQR
 * @param array - data
 * @returns - q1, median, q3, min, max, outliers
 */
export declare function xBoxPlotWithOutliers(array: NumberArray): XBoxPlotWithOutliers;
//# sourceMappingURL=xBoxPlotWithOutliers.d.ts.map