"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.xNormed = xNormed;
const getOutputArray_1 = require("./getOutputArray");
const xCheck_1 = require("./xCheck");
const xMaxValue_1 = require("./xMaxValue");
const xSum_1 = require("./xSum");
/**
 * Divides the data with either the sum, the absolute sum or the maximum of the data
 * @param input - Array containing values
 * @param options - options
 * @returns - normalized data
 */
function xNormed(input, options = {}) {
    const { algorithm = 'absolute', value = 1 } = options;
    (0, xCheck_1.xCheck)(input);
    const output = (0, getOutputArray_1.getOutputArray)(options.output, input.length);
    if (input.length === 0) {
        throw new Error('input must not be empty');
    }
    switch (algorithm) {
        case 'absolute': {
            const absoluteSumValue = absoluteSum(input) / value;
            if (absoluteSumValue === 0) {
                throw new Error('trying to divide by 0');
            }
            for (let i = 0; i < input.length; i++) {
                output[i] = input[i] / absoluteSumValue;
            }
            return output;
        }
        case 'max': {
            const currentMaxValue = (0, xMaxValue_1.xMaxValue)(input);
            if (currentMaxValue === 0) {
                throw new Error('trying to divide by 0');
            }
            const factor = value / currentMaxValue;
            for (let i = 0; i < input.length; i++) {
                output[i] = input[i] * factor;
            }
            return output;
        }
        case 'sum': {
            const sumFactor = (0, xSum_1.xSum)(input) / value;
            if (sumFactor === 0) {
                throw new Error('trying to divide by 0');
            }
            for (let i = 0; i < input.length; i++) {
                output[i] = input[i] / sumFactor;
            }
            return output;
        }
        default:
            throw new Error(`unknown algorithm: ${String(algorithm)}`);
    }
}
function absoluteSum(input) {
    let sumValue = 0;
    for (let i = 0; i < input.length; i++) {
        sumValue += Math.abs(input[i]);
    }
    return sumValue;
}
//# sourceMappingURL=xNormed.js.map