"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.xRemoveOutliersIQR = xRemoveOutliersIQR;
const is_any_array_1 = require("is-any-array");
const xBoxPlot_1 = require("./xBoxPlot");
/**
 * Remove the outliers from the array
 * Based on 1.5 IQR
 * @param array - data
 * @returns - trimmed data
 */
function xRemoveOutliersIQR(array) {
    if (!(0, is_any_array_1.isAnyArray)(array)) {
        throw new TypeError('input must be an array');
    }
    if (array.length === 0) {
        return array;
    }
    const boxPlot = (0, xBoxPlot_1.xBoxPlot)(array);
    const iqr = boxPlot.q3 - boxPlot.q1;
    const lowerWhisker = boxPlot.q1 - 1.5 * iqr;
    const higherWhisker = boxPlot.q3 + 1.5 * iqr;
    if (boxPlot.min >= lowerWhisker && boxPlot.max <= higherWhisker) {
        return array;
    }
    const filteredArray = [];
    for (const element of array) {
        if (element >= lowerWhisker && element <= higherWhisker) {
            filteredArray.push(element);
        }
    }
    return filteredArray;
}
//# sourceMappingURL=xRemoveOutliersIQR.js.map