"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.xRescale = xRescale;
const getOutputArray_1 = require("./getOutputArray");
const xCheck_1 = require("./xCheck");
const xMaxValue_1 = require("./xMaxValue");
const xMinValue_1 = require("./xMinValue");
/**
 * Function used to rescale data
 * @param input - input for the rescale
 * @param options - options
 * @returns rescaled data
 */
function xRescale(input, options = {}) {
    (0, xCheck_1.xCheck)(input);
    const output = (0, getOutputArray_1.getOutputArray)(options.output, input.length);
    const currentMin = (0, xMinValue_1.xMinValue)(input);
    const currentMax = (0, xMaxValue_1.xMaxValue)(input);
    if (currentMin === currentMax) {
        throw new RangeError('minimum and maximum input values are equal. Cannot rescale a constant array');
    }
    const { min = 0, max = 1 } = options;
    if (min >= max) {
        throw new RangeError('min option must be smaller than max option');
    }
    const factor = (max - min) / (currentMax - currentMin);
    for (let i = 0; i < input.length; i++) {
        output[i] = (input[i] - currentMin) * factor + min;
    }
    return output;
}
//# sourceMappingURL=xRescale.js.map